//+------------------------------------------------------------------+
//|                                              StochWithPoints.mq4 |
//|                                                                * |
//+------------------------------------------------------------------+
#property copyright "*"
#property link      "*"

#property indicator_separate_window
#property indicator_minimum -10
#property indicator_maximum 110
#property indicator_buffers 6
#property indicator_color1 Gold
#property indicator_width1 1
#property indicator_color2 RoyalBlue
#property indicator_width2 3
#property indicator_color3 OrangeRed
#property indicator_width3 2
#property indicator_color4 Lime
#property indicator_width4 2
#property indicator_color5 Red
#property indicator_width5 0
#property indicator_color6 Blue
#property indicator_width6 0
#property indicator_level1 10
#property indicator_level4 90
#property indicator_levelcolor DimGray
#property indicator_levelstyle STYLE_SOLID

//---- input parameters
extern int       K=7;
extern int       D=3;
extern int       S=4;
extern int       Method=0;
extern int       Price = 1;
extern int       MainHP=2;
extern int       SignalHP=2;
extern bool      DrawPoints=true;
extern bool      DrawConfirmArrow=false;
extern bool      AlertsOn =false;
extern bool      AlertsForPointsOn = false;
//extern string    SoundFile = "request.wav";
extern int       MaxBars = 500;

string Msg="", MsgPoint="";
string LastAlertMsg = "0", LastAlertMsgPoint = "0";

//---- buffers
double ExtMapBuffer1[];
double ExtMapBuffer2[];
double ExtMapBuffer3[];
double ExtMapBuffer4[];
double ExtMapBuffer5[];
double ExtMapBuffer6[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,ExtMapBuffer1);
   SetIndexLabel(0,NULL);
   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,ExtMapBuffer2);
   SetIndexLabel(1,NULL);
   
   if (DrawPoints)
   {
   SetIndexStyle(2,DRAW_ARROW);
   SetIndexArrow(2,115); //159
   SetIndexBuffer(2,ExtMapBuffer3);
   SetIndexStyle(3,DRAW_ARROW);
   SetIndexArrow(3,115);
   SetIndexBuffer(3,ExtMapBuffer4);
   }

   if (DrawConfirmArrow)
   {
   SetIndexStyle(4,DRAW_ARROW);
   SetIndexArrow(4,234);//(4,159);
   SetIndexBuffer(4,ExtMapBuffer5);
   SetIndexStyle(5,DRAW_ARROW);
   SetIndexArrow(5,233);//(5,159);
   SetIndexBuffer(5,ExtMapBuffer6);
   }
      
   SetIndexEmptyValue(5,0.0);    
   SetIndexDrawBegin(0,K+D+S);
   SetIndexDrawBegin(1,K+D+S);   
   SetIndexDrawBegin(2,K+D+S);   
   SetIndexDrawBegin(3,K+D+S);   
   SetIndexDrawBegin(4,K+D+S);   
   SetIndexDrawBegin(5,K+D+S);   
   IndicatorShortName("S_p");
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   //int limit=Bars-IndicatorCounted()-1;
   int limit=MaxBars;

      //    
      for(int i=limit;i>=0;i--)
      {
        ExtMapBuffer3[i]=EMPTY_VALUE;
        ExtMapBuffer4[i]=EMPTY_VALUE;
      }
   
      for(i=limit;i>=0;i--){
         ExtMapBuffer1[i]=iStochastic(NULL,0,K,D,S,Method,Price,0,i);
         ExtMapBuffer2[i]=iStochastic(NULL,0,K,D,S,Method,Price,1,i);         
         
         if(ArrayMaximum(ExtMapBuffer1,MainHP*2+1,i)==i+MainHP)
         ExtMapBuffer3[i+MainHP]=ExtMapBuffer1[i+MainHP];
         if(ArrayMinimum(ExtMapBuffer1,MainHP*2+1,i)==i+MainHP)
         ExtMapBuffer4[i+MainHP]=ExtMapBuffer1[i+MainHP];     
         
         if(ArrayMaximum(ExtMapBuffer2,SignalHP*2+1,i)==i+SignalHP)
         {
           ExtMapBuffer5[i+SignalHP]=ExtMapBuffer2[i+SignalHP];
           Msg = "Down";
         }
         if(ArrayMinimum(ExtMapBuffer2,SignalHP*2+1,i)==i+SignalHP)
         {
           ExtMapBuffer6[i+SignalHP]=ExtMapBuffer2[i+SignalHP];             
           Msg = "Up";
         }
      }
   
   
   if (AlertsOn && BarChanged())
   {
    if((ExtMapBuffer5[SignalHP]>0)  || (ExtMapBuffer6[SignalHP]>0) )
     if((Msg!="")&&(LastAlertMsg!=Msg))
     {
       if (LastAlertMsg!="0")
       Alert(Symbol() + " on " + PeriodToStr()+" " +Msg + " with StochPoints");
       LastAlertMsg = Msg;
     }
     
   }
  
   if (AlertsForPointsOn && BarChanged())
   {
    if((ExtMapBuffer3[MainHP]>0)  || (ExtMapBuffer4[MainHP]>0) )
    {
       if (ExtMapBuffer3[MainHP]>0) MsgPoint="Up";
          else MsgPoint="Down";
       if(LastAlertMsgPoint!=MsgPoint)
      {
         if (LastAlertMsgPoint!="0")
         Alert(Symbol() + " on " + PeriodToStr()+" pointed " +Msg + " with StochPoints");
         LastAlertMsgPoint = MsgPoint;
      }
    }
     
   }
   
   
   return(0);
   
   
  }
//+------------------------------------------------------------------+


void DrawPointButton()
{



}

bool BarChanged()
{
 static datetime dt = 0;

  if (dt != Time[0])
  {
   dt = Time[0];
   return(true);
  }
   return(false);
}

void CreateLabel(string aLabelName, string aLabelText, int aXDISTANCE, int aYDISTANCE, color aColor)
{
   ObjectDelete(aLabelName);
   ObjectCreate(aLabelName, OBJ_LABEL, WindowFind("S_p"), 0, 1.0);
   ObjectSet(aLabelName, OBJPROP_CORNER, 1);
   ObjectSet(aLabelName, OBJPROP_XDISTANCE, aXDISTANCE);
   ObjectSet(aLabelName, OBJPROP_YDISTANCE, aYDISTANCE);
   ObjectSetText(aLabelName, aLabelText, 16, "Arial", aColor);
}

string PeriodToStr()
{
  string _Result;

  switch (Period())
  {
    case 1:    _Result = "m1";  break;
    case 5:    _Result = "m5";  break;
    case 15:   _Result = "m15"; break;
    case 30:   _Result = "m30"; break;
    case 60:   _Result = "h1";  break;
    case 240:  _Result = "h4";  break;
    case 1440: _Result = "d1";  break;
  }
   
  return(_Result);
}